# Arby

[Model Order Reduction (MOR)](https://en.wikipedia.org/wiki/Model_order_reduction) is a technique for reducing the computational complexity of mathematical models in numerical simulations.

Arby is a fully data-driven Python module to construct reduced order basis, empirical interpolants and surrogate models from training data.

# License

MIT

# Documentation



***

(c) 2020 Aaron Villanueva
